@@ -1,8 +1,7 @@
 import unittest
+from unittest import mock
 
 from click.testing import CliRunner as CLIRunner
-from click import utils as click_utils
-import mock
 
 from git_pw import bundle
 
@@ -125,7 +124,7 @@ class DownloadTestCase(unittest.TestCase):
         mock_get_bundle.assert_called_once_with('123')
         mock_download.assert_called_once_with(rsp['mbox'], output=mock.ANY)
         assert isinstance(
-            mock_download.call_args[1]['output'], click_utils.LazyFile,
+            mock_download.call_args[1]['output'], str,
         )
 
 
